DA_STR_SIZE = 256
MAX_BROKER = 4096
DAAPI_VERSION = "1.12"
OS_NAME = "Windows"
OS_NAME = "Linux"
MAX_SUB_COUNT = 20
DAF_TYPE_Stock = 'S'
DAF_TYPE_Future = 'D'
DAF_TYPE_Unknown = 0
DAF_SUB_Append = '1'
DAF_SUB_Replace = '2'
DAF_SUB_Unsubcribe = '3'
DAF_SUB_UnsubcribeAll = '4'
DAF_Market_Full = 'Z'
DAF_Market_Fill = 'Y'
